# 5-26-20 manually read csv files

library(tidyverse)
library(broom)
library(ggfortify)
library(lubridate)

## 5-26-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))

# Read in Baseline Data -------------------------------------
F89BL11 <- read_csv("C:/Users/skoike/Desktop/tidy data/11ASPEXD/F89BL11.csv")
F89DW11 <- read_csv("C:/Users/skoike/Desktop/tidy data/11ASPEXD/f89dw11.csv")
F89H11 <- read_csv("C:/Users/skoike/Desktop/tidy data/11ASPEXD/F89H11.csv")

data.list <- list("F89BL11" = F89BL11, "F89DW11" = F89DW11, "F89H11" = F89H11)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F89BL11

glimpse(F89BL11) # Pre & post-trtmt baseline growth measures

OZ.rlvl <- c("CONTROL", "EPLOW", "EPHIGH", "DAILY", "HELLOW", "HELHI")

F89BL11.copy <- F89BL11 %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         OZ = recode(OZ, CONTRL = "CONTROL"), # Recoding OZ for later joining
         OZ = fct_relevel(OZ, OZ.rlvl))  


## Harvest 1- Hvst 1 biomass dry wts

glimpse(F89DW11) 

F89DW11.copy <- F89DW11 %>% 
  mutate(DATE = days(DATE) + mdy("1/01/1960"), # DATE = days past Jan. 1 1960
         OZ = as_factor(OZ),
         LEAFDW = as.numeric(LEAFDW), # These are encoded as chr, convert to double
         TOTALDW = LEAFDW + STEMDW + ROOTDW) %>%  
  filter(CH != 90) %>% # 90 is a non-chamber
  droplevels() # Don't want NOO3 level in OZ factor

### F89H11- Hvst 1 growth measures, lengths & areas

glimpse(F89H11)

F89H11.copy <- F89H11 %>% 
  mutate(DATE = mdy(DATE),
         VOL = HT * DIAM^2) %>% # Add Volume 
  filter(CH != 88) %>% # Pre-treatment harvest # 88 is a non-chamber
  mutate(OZ = as_factor(OZ),
         OZ = recode(OZ, CONTRL = "CONTROL"),
         OZ = fct_relevel(OZ, OZ.rlvl)) # Recode for later joining


# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest1.data <- full_join(F89DW11.copy, F89H11.copy, by = c("CH", "PLT", "DATE", "OZ", "O3", "ID"))

#View(harvest1.data)

# Joining Harvest and Base Line Data -------------------------------------------------

H1 <- left_join(harvest1.data, F89BL11.copy, 
                by = c("CH", "PLT", "ID", "LOCAT", "PROJ", "OZ", "O3", "SPECIES"),
                suffix = c(".h1", ".bl"))

# Add log transformation and recode CH as a factor

H1 <- H1 %>% 
  filter(ROOTDW != 0) %>% 
  mutate(LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL.bl = log(VOL.bl + 0.01),
         LOGVOL.h1 = log(VOL.h1 + 0.01),
         CH = as_factor(CH))

raw_data <- H1 %>% select(SPECIES, OZ, O3, ID, CH, PLT, VOL.bl, VOL.h1, LEAFDW, STEMDW, ROOTDW, TOTALDW, 
                          LOGVOL.bl, LOGVOL.h1, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW,
                          DATE.bl, DATE.h1)
#write.csv(raw_data, "11_h1_raw.csv", row.names = FALSE)

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL.bl, fill = OZ) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>%  
  ggplot() + 
  aes(x = OZ, y = LOGTOTALDW) + # Post-trt DW by trt
  geom_boxplot() + 
  ggtitle("Harvest 1 Log Total Dry Weight by Treatment")

H1 %>% 
  group_by(CH, PLT) %>% 
  summarise(before = LOGVOL.bl, after = LOGVOL.h1) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after) + 
  geom_point(alpha = 1/2) +
  geom_smooth(method = "lm", se = FALSE)


H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(before = VOL.bl, after = VOL.h1) %>% 
  pivot_longer(cols = c("before", "after"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")


H1 %>% 
  group_by(OZ) %>% 
  summarize(logmeanBefore = mean(LOGVOL.bl), 
            logmeanAfter = mean(LOGVOL.h1),
            logmeanStem = mean(LOGSTEMDW, na.rm = T),
            logmeanLeaf = mean(LOGLEAFDW, na.rm = T),
            logmeanRoot = mean(LOGROOTDW),
            logmeanTotal = mean(LOGTOTALDW, na.rm = T)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL.bl), mean, na.rm = TRUE)

#write.csv(test.df, "11_h1_means.csv", row.names = FALSE)

# Get Ozone Exposure Metrics --------------------------------------------------------

# Want 1989 data and exposure data in range of 06-06-1989 to 9-18-1989
otest1 <- ferfoz %>%
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-06-1989"), mdy("09-18-1989")))
exp_days <- as.numeric(mdy("09-18-1989") - mdy("06-06-1989") + 1)

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# (Ozone) Exposure Metrics:
otest.89.df <- OZ.metrics(otest1) %>% 
  filter(CH %in% levels(test.df$CH)) %>% 
  droplevels() %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})



test_long <- full_join(H1 %>% select(OZ, CH, PLT, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL.bl),
                       otest.89.df) %>% 
  rename(LOGVOL_bl = LOGVOL.bl)

#write.csv(test_long, "11_h1_data.csv", row.names = FALSE)

test2.df <- left_join(test.df, otest.89.df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1989,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())
#View(test2.df)

#write.csv(test2.df, "11_h1_mean_data.csv", row.names = FALSE)
