# 06-01-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-01-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))

# Read in Baseline Data -------------------------------------
F90BL25 <- read_csv("C:/Users/skoike/Desktop/tidy data/25SMEXDY/F90BL25.csv")
F90DW25 <- read_csv("C:/Users/skoike/Desktop/tidy data/25SMEXDY/F90DW25.csv")
F90H25 <- read_csv("C:/Users/skoike/Desktop/tidy data/25SMEXDY/F90H25.csv")


data.list <- list("F90BL25" = F90BL25, "F90DW25" = F90DW25, "F90H25" = F90H25)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F90BL25

glimpse(F90BL25) # Pre-, interim & post-trtmt baseline growth measures & bud cnts
summary(F90BL25)

OZ.rlvl <- c("CONTROL", "EPXLOW", "EPHIGH", "XLOWHI", "HIXLOW")
noNeg <- function(x){ifelse(x < 0, NA, x)} 

F90BL25.copy <- F90BL25 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate( DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH)) %>% 
  filter(DATE == mdy("05-18-1990"))

#View(F90BL25.copy)

## F90DW25- Hvst growth measures, cnts & areas

#glimpse(F90DW25) 
not.all.NA <- function(x){!all(is.na(x))}

F90DW25.copy <- F90DW25 %>% 
  filter(CH != 0) %>% 
  droplevels() %>% # Don't want NOO3 level in OZ factor
  mutate_at(11:23, as.numeric) %>% 
  select_if(not.all.NA) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         CH = as_factor(CH),
         ROOTDW = CROOTSS + FROOTSS,
         TOTALDW = LFSSCHDW + STEMCHDW + ROOTDW) %>% 
  rename(LEAFDW = LFSSCHDW,
         STEMDW = STEMCHDW)

### F90H25- Hvst 1 growth measures, lengths & areas

#glimpse(F90H25)

F90H25.copy <- F90H25 %>% 
  filter(CH != 0) %>% 
  droplevels() %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         VOL = HT * DIAM^2, # Add Volume 
         CH = as_factor(CH)) %>% 
  select(-HTSCAR, -NOTE)

# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest1.data <- full_join(F90DW25.copy, F90H25.copy, 
                           by = c("CH", "PLT", "DATE", "DAY", "OZ", "O3", "ID", "PROJ", "LOCAT", "SPECIES"))

#View(harvest1.data)

# Joining Harvest and Base Line Data -------------------------------------------------

H1 <- left_join(harvest1.data, F90BL25.copy, 
                by = c("PROJ", "LOCAT", "SPECIES", "OZ", "O3", "ID",
                "CH", "PLT"),
                suffix = c(".h", ".bl"))

# Add log transformation and recode CH as a factor
H1 <- H1 %>% 
  mutate(LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL.bl = log(VOL.bl + 0.01),
         LOGVOL.h = log(VOL.h + 0.01))

raw_data <- H1 %>% select(SPECIES, OZ, O3, ID, CH, PLT, VOL.bl, VOL.h, LEAFDW, STEMDW, ROOTDW, TOTALDW, 
                          LOGVOL.bl, LOGVOL.h, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW,
                          DATE.bl, DATE.h)
#write.csv(raw_data, "25_h1_raw.csv", row.names = FALSE)

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL.bl) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  group_by(CH, PLT) %>% 
  summarise(before = VOL.bl, after = VOL.h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE)

H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(before = VOL.bl, after = VOL.h) %>% 
  pivot_longer(cols = c("before", "after"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H1 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL.bl), 
            meanVolAfter = mean(LOGVOL.h, na.rm = TRUE)) # Summarize mean log-volume by treatment


# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL.bl), mean, na.rm = TRUE) %>% 
  select(-LOGVOL.h)

#write.csv(test.df, "25_h1_means.csv", row.names = FALSE)

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1990 data and exposure data in range of 05-16-1990 to 10-03-1990
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("05-16-1990"), mdy("10-03-1990")))

exp_days <- as.numeric(mdy("10-03-1990") - mdy("05-16-1990") + 1)

otest.90.df <- OZ.metrics(otest1) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days}) %>% 
  filter(CH %in% levels(test.df$CH)) %>% 
  droplevels()

test_long <- full_join(H1 %>% 
                         select(OZ, CH, PLT, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL.bl) %>% 
                         rename(LOGVOL_bl = LOGVOL.bl),
                       otest.90.df)

#write.csv(test_long, "25_h1_data.csv", row.names = FALSE)

#write.csv(otest.90.df, "25_h1_oz_metrics.csv", row.names = FALSE)

test2.df <- left_join(test.df, otest.90.df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1990,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())
#View(test2.df)

#write.csv(test2.df, "25_h1_mean_data.csv", row.names = FALSE)
