# Get Ozone Exposure Metrics For Split Chambers -------------------------------------

# (Ozone) Exposure Metrics:

OZ.switch.metrics <- function(data, CH1, CH2, split_date){
  
  require(lubridate)
  
  # We are trying to create Ozone metrics for plants who move between chambers in the middle of a growing season
  
  joinedCH <- as_factor(CH1):as_factor(CH2) # Create a label for the chamber 1 / chamber 2 combination
  
  otestA <- data %>% 
    filter(date <= split_date,
           ch == CH1) # The ozone measurements for the first chamber
  
  otestB <- data %>% 
    filter(date > split_date,
           ch == CH2) # The ozone measurements for the second chamber
  
  ## WXX- Sinusoidal
  wxx <- function(actual, xx = 126){
    wxx <- actual/(1 + 4403*exp(-xx*actual)) # default xx = 126
    return(wxx)
  }
  
  ## AOTXX- Flat subtract
  aotxx <- function(actual, xx){
    aotxx <- actual - xx #the metric
    aotxx <- ifelse(aotxx < 0, 0, aotxx) #set aotxx to 0 if (aotxx < 0) 
    return(aotxx)
  }
  
  ## SumXX- Indicator
  sumxx <- function(actual, xx){
    sumxx <- ifelse(actual < xx, 0, actual) #set sumxx to 0 if (actual < xx)
    return(sumxx)
  }
  
  ## NXX
  nxx <- function(actual, xx){
    nxx <- ifelse(actual < xx, 0, 1) #set nxx to 0 if (actual < xx) and to 1 otherwise
    return(nxx)
  }
  
  # Add various metrics to data frame (first half of season)
  otest1C <- otestA %>% 
    mutate(w126 = wxx(actual),
           aot40 = aotxx(actual, 0.04),
           aot50 = aotxx(actual, 0.05),
           aot60 = aotxx(actual, 0.06),
           aot70 = aotxx(actual, 0.07),
           aot80 = aotxx(actual, 0.08),
           aot90 = aotxx(actual, 0.09),
           aot100 = aotxx(actual, 0.10),
           sum06 = sumxx(actual, 0.06),
           sum07 = sumxx(actual, 0.07),
           sum08 = sumxx(actual, 0.08),
           sum09 = sumxx(actual, 0.09),
           sum10 = sumxx(actual, 0.10),
           n08 = nxx(actual, 0.08),
           n09 = nxx(actual, 0.09),
           n10 = nxx(actual, 0.10),
           n11 = nxx(actual, 0.11),
           n12 = nxx(actual, 0.12),
           n13 = nxx(actual, 0.13),
           n14 = nxx(actual, 0.14),
           n15 = nxx(actual, 0.15)
    )
  
  # Add various metrics to data frame (second half of season)
  otest2C <- otestB %>% 
    mutate(w126 = wxx(actual),
           aot40 = aotxx(actual, 0.04),
           aot50 = aotxx(actual, 0.05),
           aot60 = aotxx(actual, 0.06),
           aot70 = aotxx(actual, 0.07),
           aot80 = aotxx(actual, 0.08),
           aot90 = aotxx(actual, 0.09),
           aot100 = aotxx(actual, 0.10),
           sum06 = sumxx(actual, 0.06),
           sum07 = sumxx(actual, 0.07),
           sum08 = sumxx(actual, 0.08),
           sum09 = sumxx(actual, 0.09),
           sum10 = sumxx(actual, 0.10),
           n08 = nxx(actual, 0.08),
           n09 = nxx(actual, 0.09),
           n10 = nxx(actual, 0.10),
           n11 = nxx(actual, 0.11),
           n12 = nxx(actual, 0.12),
           n13 = nxx(actual, 0.13),
           n14 = nxx(actual, 0.14),
           n15 = nxx(actual, 0.15),
    )
  
  # Summarize Data by Exposure Windows ---------------------------------------------
  
  
  ### Looking at 24 hr exposure window
  # glimpse(otest1C) to get the columns to specify
  
  joining = c("program", "julian", "expoday", "trt", "ch", "n", "actual", 
              "stdev", "request", "date", "datetime", "year", "month", "day", 
              "hour", "w126", "aot40", "aot50", "aot60", "aot70", "aot80", "aot90", 
              "aot100", "sum06", "sum07", "sum08", "sum09", "sum10", "n08", "n09", 
              "n10", "n11", "n12", "n13", "n14", "n15") # Labels to suppress messages during joining
  
  otest.full <- full_join(otest1C, otest2C, by = joining) %>% # Join the data two chambers
    mutate(joinedCH)
  
  otests <- otest.full %>% 
    group_by(joinedCH) %>% 
    summarize_at(vars(actual, w126:n15), sum, na.rm = TRUE) # Summarize the metrics for the different metrics
  #View(otest.full)
  
  # Number of Observations (and non-NA observations) by chamber 
  otest.length <- otest.full %>% 
    group_by(joinedCH) %>% 
    summarize(ot6 = length(actual), # number of data points for actual
              ot7 = sum(!is.na(actual)), # number of non-NA data points for actual
              prop = ot6/ot7) 
  
  ## Looking at exposures over a window of time
  
  ### Looking at times *between* 8 am and 8 pm (B-Test)
  
  btest <- otest.full %>% 
    filter(hour > 7 & hour < 20) # Get the hours
  
  btest.summary <- btest %>% 
    group_by(joinedCH) %>% 
    summarize_at(vars(actual, w126:n15), sum, na.rm = TRUE) # sum of 'actual' and all metrics, grouped by chamber
  
  #### B-Test Sample Size: Number of 'actual' readings (and non-NA 'actual' readings) by chamber during B-Test
  
  btest.summary.length <- btest %>% 
    group_by(joinedCH) %>% 
    summarize(ot6b = length(actual), # number of data points for actual
              ot7b = sum(!is.na(actual)), # number of non-NA data points for actual
              prop = ot6b/ot7b)
  
  
  ### Looking at times *between* 9 am and 8 pm (C-Test)
  
  ctest <- otest.full %>% 
    filter(hour > 8 & hour < 21) # get the hours
  
  ctest.summary <- ctest %>% 
    group_by(joinedCH) %>% 
    summarize_at(vars(actual, w126:n15), sum, na.rm = TRUE) # sum of 'actual' and all metrics, grouped by chamber
  
  #### C-Test Sample Size: Number of 'actual' readings (and non-NA 'actual' readings) by chamber during C-Test
  
  ctest.summary.length <- ctest %>% 
    group_by(joinedCH) %>% 
    summarize(ot6c = length(actual), # number of data points for actual
              ot7c = sum(!is.na(actual)), # number of non-NA data points for actual
              prop = ot6c/ot7c) 
  
  
  ### Looking at times *between* 7 am and 6 pm (D-Test)
  
  dtest <- otest.full %>% 
    filter(hour > 6 & hour < 19)
  
  dtest.summary <- dtest %>% 
    group_by(joinedCH) %>% 
    summarize_at(vars(actual, w126:n15), sum, na.rm = TRUE)
  
  
  #### D-Test Sample Size: Number of 'actual' readings (and non-NA 'actual' readings) by chamber during D-Test
  
  dtest.summary.length <- dtest %>% 
    group_by(joinedCH) %>% 
    summarize(ot6d = length(actual), # number of data points for actual
              ot7d = sum(!is.na(actual)), # number of non-NA data points for actual
              prop = ot6d/ot7d) 
  
  
  ## 4th Highest Daily Max: Extract the 4th highest exposure level, by the two chamber, over all exposure days
  
  otesthdm4 <- otest.full %>% 
    group_by(ch, joinedCH, expoday) %>% # group by chamber and day
    summarize(dailyhigh = max(actual, na.rm = TRUE)) %>% # find the daily maximum O3 in a chamber for all days
    arrange(ch, desc(dailyhigh)) %>%  # arrange the exposure levels from high to low (again at chamber level)
    slice(4) %>% # take the 4th highest daily maximum for that chamber
    select(-expoday) %>% # discard exposure day 
    pivot_wider(names_from = ch, values_from = dailyhigh, names_prefix = "hdm4_") # Make it wider for joining 
  
  # Join Summary Data Together -------------------------------------------------
  
  # Join Data and add suffices
  otest.df <- full_join(otests, btest.summary, by = "joinedCH", suffix = c(".24", ".12.8")) %>% # Combine 24 hr metrics with 12 hr (8am - 8pm)
    full_join(ctest.summary, by = "joinedCH") %>% # Combine with 12 hr window (9 am to 8 pm)
    full_join(dtest.summary, by = "joinedCH", suffix = c(".12.9", ".12.7")) %>% # Combine with 12 hr window (7 am to 6 pm)
    full_join(otesthdm4, by = "joinedCH") # add 4th highest daily max
  
  # Since there are some missing data, we weight exposure metrics for each time period of interest
  
  ## Recall prop = weight to offset NA data points
  
  ### Adjustment for 24-hr period
  adjusted.24 <- otest.df %>% 
    select(joinedCH, ends_with(".24")) %>% 
    mutate_at(vars(-joinedCH), function(x){x*otest.length$prop})
  
  ### Adjustment for 12-hr period B-Test
  adjusted.12.8 <- otest.df %>% 
    select(joinedCH, ends_with(".12.8")) %>% 
    mutate_at(vars(-joinedCH), function(x){x*btest.summary.length$prop})
  
  ### Adjustment for 12-hr period C-Test
  adjusted.12.9 <- otest.df %>% 
    select(joinedCH, ends_with(".12.9")) %>% 
    mutate_at(vars(-joinedCH), function(x){x*ctest.summary.length$prop})
  
  ### Adjustment for 12-hr period D-Test
  adjusted.12.7 <- otest.df %>% 
    select(joinedCH, ends_with(".12.7")) %>% 
    mutate_at(vars(-joinedCH), function(x){x*dtest.summary.length$prop})
  
  ## Join with Metrics Data 
  otest.df <- otest.df %>% 
    full_join(adjusted.24, by = "joinedCH", suffix = c("", ".adj")) %>% 
    full_join(adjusted.12.7, by = "joinedCH", suffix = c("", ".adj")) %>% 
    full_join(adjusted.12.8, by = "joinedCH", suffix = c("", ".adj")) %>% 
    full_join(adjusted.12.9, by = "joinedCH", suffix = c("", ".adj"))
  
  return(otest.df)
}