# 06-09-20 manually read csv files

library(tidyverse)
library(broom)
library(ggfortify)
library(lubridate)

## 06-09-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))

# Read in Baseline Data -------------------------------------
F93BL48 <- read_csv("C:/Users/skoike/Desktop/tidy data/48PPEXDY/F93BL48.csv")
F93H48P1 <- read_csv("C:/Users/skoike/Desktop/tidy data/48PPEXDY/F93H48P1.csv")

data.list <- list("F93BL48" = F93BL48, "F93H48P1" = F93H48P1)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F93BL48

glimpse(F93BL48) # Pre- & post-trtmt baseline growth & length measures


F93BL48.copy <- F93BL48 %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ)) 


## Harvest 1- Post-trtmt hvst growth measures, cnts, lengths, subsamples & biomass dry wts

glimpse(F93H48P1) 
noNeg <- function(x){ifelse(x == -99, NA, x)}

harvest1.data <- F93H48P1 %>% 
  rename(NEEDLEDW = TNDW,
         STEMDW = STDW,
         ROOTDW = TRTDW,
         TOTALDW = TPLTDW) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), 
         OZ = as_factor(OZ),
         VOL = HT*DIAM^2)

# Joining Harvest and Base Line Data -------------------------------------------------
H1 <- left_join(harvest1.data, F93BL48.copy, 
                by = c("CH93", "PLT", "ID", "OZ", "O3", "SEQ"),
                suffix = c(".h", ".bl"))

# Add log transformation and recode CH as a factor

H1 <- H1 %>% 
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL.bl = log(VOL.bl + 0.01),
         LOGVOL.h = log(VOL.h + 0.01),
         CH = as_factor(CH93))
# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL.bl, fill = OZ) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>%  
  ggplot() + 
  aes(x = OZ, y = LOGTOTALDW) + # Post-trt DW by trt
  geom_boxplot() + 
  ggtitle("Harvest 1 Log Total Dry Weight by Treatment")

H1 %>% 
  group_by(CH, PLT) %>% 
  summarise(before = LOGVOL.bl, after = LOGVOL.h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after) + 
  geom_point(alpha = 1/2) +
  geom_smooth(method = "lm", se = FALSE)


H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(before = VOL.bl, after = VOL.h) %>% 
  pivot_longer(cols = c("before", "after"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")


H1 %>% 
  group_by(OZ) %>% 
  summarize(logmeanVolBefore = mean(LOGVOL.bl, na.rm = T), 
            logmeanVolAfter = mean(LOGVOL.h, na.rm = T),
            logmeanStem = mean(LOGSTEMDW, na.rm = T),
            logmeanNeedle = mean(LOGNEEDLEDW, na.rm = T),
            logmeanRoot = mean(LOGROOTDW, na.rm = T),
            logmeanTotal = mean(LOGTOTALDW, na.rm = T)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL.bl), mean, na.rm = TRUE)

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1993 data and exposure data in range of 06-01-1993 to 9-21-1993
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-01-1993"), mdy("09-21-1993")))
exp_days <- as.numeric(mdy("09-21-1993") - mdy("06-01-1993") + 1)

otest.93.df <- OZ.metrics(otest1)

# (Ozone) Exposure Metrics:
otest.93.df <- otest.93.df %>% 
  filter(CH %in% levels(test.df$CH)) %>% 
  droplevels() %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(H1 %>% select(OZ, CH, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL.bl),
                       otest.93.df) %>% 
  rename(LOGVOL_bl = LOGVOL.bl)

#write.csv(test_long, "48_h1_data.csv", row.names = FALSE)

test2.df <- left_join(test.df, otest.93.df) %>% 
  ungroup() %>% 
  mutate(Year = 1993,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything(), -LOGVOL.h, -N2SSDW, 
         -N2RSTDW, -TN2DW, -N3SSDW, -N3RSTDW, -TN3DW, -TAPRTDW, -LATRTDW) %>% 
  rename(VOL_bl = VOL.bl,
         LOGVOL_bl = LOGVOL.bl)

#View(test2.df)

#write.csv(test2.df, "48_h1_mean_data.csv", row.names = FALSE)
