library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in data -------------------------------------

oz90 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/OZONE/ozone90dk.csv")

pine90 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/eastern_white_pine/PINE1990.csv")

# Clean up data ------------------------------------
noNA <- function(x){ifelse(x == -99, NA, x)} # Sets -99 to NA
noNeg <- function(x){ifelse(x < 0, 0, x)} # Sets erroneous negative values to 0

oz90 <- oz90 %>% 
  mutate(date = make_date(1900 + year, month, day),
         datetime = make_datetime(1900 + year, month, day, hour)) %>% # Create Date variables
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNA) %>% 
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNeg)

pine90 <- pine90 %>% 
  mutate_if(is.numeric, noNA) %>% 
  rename(NEEDLE = LEAF) %>% 
  mutate(TOTAL = NEEDLE + STEM + ROOT, # Create other response variables
         CHAMB = as_factor(CHAMB),
         TREAT = as_factor(TREAT),
         LOGNEEDLE = log(NEEDLE + 0.01),
         LOGSTEM = log(STEM + 0.01),
         LOGROOT = log(ROOT + 0.01),
         LOGTOTAL = log(TOTAL + 0.01),
         VOL = HT * DIAM^2,
         LOGVOL = log(VOL + 0.01)) %>% 
  rename(NEEDLEDW = NEEDLE,
         STEMDW = STEM,
         ROOTDW = ROOT,
         TOTALDW = TOTAL)

# Exploratory Data Analysis -------------------------

oz90_long <- oz90 %>% 
  pivot_longer(cols = starts_with("OZ") | starts_with("SDOZ"),
               names_to = c("Measurement", "Level"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value)

ord_CHAMB <- as.character(1:18)

oz90_long <- oz90_long %>% 
  mutate(CHAMB = case_when(Level == "18" ~ "1",
                           Level == "02" ~ "2",
                           Level == "13" ~ "3",
                           Level == "06" ~ "4",
                           Level == "04" ~ "5",
                           Level == "08" ~ "6",
                           Level == "14" ~ "7",
                           Level == "05" ~ "8",
                           Level == "03" ~ "9",
                           Level == "01" ~ "10",
                           Level == "17" ~ "11",
                           Level == "12" ~ "12",
                           Level == "10" ~ "13",
                           Level == "09" ~ "14",
                           Level == "07" ~ "15",
                           Level == "15" ~ "16",
                           Level == "16" ~ "17",
                           TRUE ~ "18")) %>% 
  mutate(CHAMB = factor(CHAMB, levels = ord_CHAMB))

oz90_long %>% 
  ggplot() + 
  aes(x = datetime, y = OZ/1000) + 
  geom_line() + 
  facet_wrap(. ~ CHAMB)

summ_stats_oz <- oz90_long %>% 
  group_by(CHAMB, Level) %>% 
  summarize(mean = mean(OZ, na.rm = TRUE),
            sd = sd(OZ, na.rm = TRUE),
            median = median(OZ, na.rm = TRUE), 
            n = n(),
            NAs = sum(is.na(OZ)),
            prop_NA = NAs / n)
summ_stats_oz

summ_stats_oz %>% 
  ggplot() + 
  aes(x = CHAMB, y = prop_NA) + 
  geom_bar(stat = "identity")

# Create OZ Metrics -----------------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/KARNOSKY/Seiji's Work/OZ_metrics_KARN.R")

exp_days <- as.numeric(max(oz90_long$date) - min(oz90_long$date) + 1)

stest <- OZ_metrics_KARN(oz90_long) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(pine90 %>% select(TREAT, CHAMB, PLANT, LOGVOL, LOGNEEDLE, LOGSTEM, LOGROOT, LOGTOTAL),
                       stest)

#write.csv(test_long, "ewp_90_data.csv", row.names = FALSE)

# Combine Maple Data with OZ metrics -------------------------------------------
test.df <- pine90  %>% 
  filter(TREAT != 0) %>%  
  group_by(TREAT, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL), mean, na.rm = TRUE) %>% 
  rename(LOGNEEDLEDW = LOGNEEDLE,
         LOGSTEMDW = LOGSTEM,
         LOGROOTDW = LOGROOT,
         LOGTOTALDW = LOGTOTAL,
         LOGVOL_bl = LOGVOL,
         VOL_bl = VOL)

combined_data <- full_join(test.df, stest) %>% 
  mutate(Year = 1990,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(combined_data, "ewp_90_mean_data.csv", row.names = FALSE)
