library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in data -------------------------------------

oz91 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/OZONE/ozone91dk.csv")

pine91 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/eastern_white_pine/PINE1991.csv")

# Clean up data ------------------------------------
noNA <- function(x){ifelse(x == -99, NA, x)} # Sets -99 to NA
noNeg <- function(x){ifelse(x < 0, 0, x)} # Sets erroneous negative values to 0

oz91 <- oz91 %>% 
  mutate(date = make_date(1900 + year, month, day),
         datetime = make_datetime(1900 + year, month, day, hour)) %>% # Create Date variables
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNA) %>% 
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNeg)

pine91 <- pine91 %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(NEEDLE = OLDNEEDLE + NEWNEEDLE,
         TOTAL = NEEDLE + STEM + ROOT, # Create other response variables
         CHAMB = as_factor(CHAMB),
         TREAT = as_factor(TREAT),
         LOGNEEDLE = log(NEEDLE + 0.01),
         LOGSTEM = log(STEM + 0.01),
         LOGROOT = log(ROOT + 0.01),
         LOGTOTAL = log(TOTAL + 0.01)) %>% 
  rename(NEEDLEDW = NEEDLE,
         STEMDW = STEM,
         ROOTDW = ROOT,
         TOTALDW = TOTAL)


# Exploratory Data Analysis -------------------------

pine91_long <- pine91 %>% 
  pivot_longer(cols = c(HT1, HT2, HT3, HT4, HT5, DIAM1, DIAM2, DIAM3, DIAM4, DIAM5), 
               names_to = c("Measurement", "Step"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(VOL = HT * DIAM^2,
         LOGVOL = log(VOL + 0.01),
         ID = as_factor(CHAMB):as_factor(PLANT))

pine91_wide <- pine91_long %>% 
  pivot_wider(names_from = Step, 
              values_from = c("HT", "DIAM", "VOL", "LOGVOL")) 

pine91 <- pine91 %>% 
  select(-starts_with("HT"), -starts_with("DIAM")) %>% 
  full_join(pine91_wide)

vol_change <- pine91 %>% 
  ggplot() + 
  aes(x = LOGVOL_1, y = LOGVOL_4, color = TREAT) + 
  geom_point(size = 2) + 
  scale_color_manual(values = brewer.pal(6, "Dark2")) + 
  geom_smooth(method = "lm", se = FALSE) 
vol_change
vol_change + 
  geom_smooth(method = "lm", linetype = "dashed", color = "black",
              aes(group = 1))

vol_change + facet_wrap(. ~ TREAT)

pine91_long %>% 
  ggplot() + 
  aes(x = Step, y = LOGVOL, group = ID) + 
  geom_point() + 
  geom_line() + 
  facet_wrap(. ~ TREAT) # Some volumes don't make any sense because of a decrease

pine91_wide %>% 
  group_by(CHAMB) %>% 
  summarise(weird = sum(LOGVOL_5 < LOGVOL_1, na.rm = T)) # Some end volumes smaller than initial

pine91_wide %>% 
  filter(.$LOGVOL_5 < .$LOGVOL_1) %>% 
  pivot_longer(cols = c(LOGVOL_1, LOGVOL_5)) %>% 
  ggplot() + 
  aes(x = name, y = value, group = ID) + 
  geom_text(aes(label = ID)) + 
  geom_line() + 
  facet_wrap(. ~ TREAT) #Here they are!
  

oz91_long <- oz91 %>% 
  pivot_longer(cols = starts_with("OZ") | starts_with("SDOZ"),
               names_to = c("Measurement", "Level"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(CHAMB = factor(as.numeric(Level)))

summ_stats_oz <- oz91_long %>% 
  group_by(CHAMB, Level) %>% 
  summarize(mean = mean(OZ, na.rm = TRUE),
            sd = sd(OZ, na.rm = TRUE),
            median = median(OZ, na.rm = TRUE), 
            n = n(),
            NAs = sum(is.na(OZ)),
            prop_NA = NAs / n)
summ_stats_oz

summ_stats_oz %>% 
  ggplot() + 
  aes(x = CHAMB, y = prop_NA) + 
  geom_bar(stat = "identity")


# Create OZ Metrics -----------------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/KARNOSKY/Seiji's Work/OZ_metrics_KARN.R")

exp_days <- as.numeric(max(oz91_long$date) - min(oz91_long$date) + 1)

stest <- OZ_metrics_KARN(oz91_long) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(pine91 %>% select(TREAT, CHAMB, PLANT, LOGVOL_1, LOGNEEDLE, LOGSTEM, LOGROOT, LOGTOTAL),
                       stest)

#write.csv(test_long, "ewp_91_data.csv", row.names = FALSE)

# Combine Maple Data with OZ metrics -------------------------------------------
test.df <- pine91 %>% 
  group_by(TREAT, CHAMB) %>% 
  summarise_at(vars(contains("VOL_1"), ends_with("DW"), LOGNEEDLE, LOGSTEM, LOGROOT, LOGTOTAL), mean, na.rm = TRUE) %>% 
  rename(LOGNEEDLEDW = LOGNEEDLE,
         LOGSTEMDW = LOGSTEM,
         LOGROOTDW = LOGROOT,
         LOGTOTALDW = LOGTOTAL,
         LOGVOL_bl = LOGVOL_1,
         VOL_bl = VOL_1)

combined_data <- full_join(test.df, stest) %>% 
  mutate(Year = 1991,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(combined_data, "ewp_91_mean_data.csv", row.names = FALSE)
