library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in data -------------------------------------

oz90 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/OZONE/ozone90dk.csv")

clone90 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/ASPEN/CLONE/CLON1990.csv")

harvest <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/ASPEN/CLONE/HARVEST.csv")

# Clean up data ------------------------------------
noNA <- function(x){ifelse(x == -99, NA, x)} # Sets -99 to NA
noNeg <- function(x){ifelse(x < 0, 0, x)} # Sets erroneous negative values to 0

oz90 <- oz90 %>% 
  mutate(date = make_date(1900 + year, month, day),
         datetime = make_datetime(1900 + year, month, day, hour)) %>% # Create Date variables
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNA) %>% 
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNeg)

clone90 <- clone90 %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(TREAT = as_factor(TREAT),
         CHAMB = as_factor(CHAMB),
         PLANT = as_factor(PLANT),
         CLONE = as_factor(CLONE)
  )
dim(clone90)

harvest <- harvest %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(STEM = OLDSTEM + NEWSTEM,
         ROOT = COARSE + FINE,
         TOTAL = STEM + LEAF + ROOT,
         TREAT = as_factor(TREAT),
         CHAMB = as_factor(CHAMB),
         PLANT = as_factor(PLANT),
         CLONE = as_factor(CLONE)
  )
dim(harvest)
#View(harvest)

harvest %>% group_by(TREAT) %>% tally() # How many plants per treatment

harvest %>% arrange(PLANT) 
(dupl <- harvest %>% group_by(TREAT, CHAMB, PLANT, CLONE) %>% tally() %>% filter(n != 1)) # Duplicates?

left_join(dupl %>% select(-n), harvest) # Where is it in the harvest data

harvest %>% # Mean Weight by Treatment, Measurement, and Clone
  group_by(TREAT, CLONE) %>% 
  summarize_at(vars(LEAF, TOTAL, STEM, ROOT), mean, na.rm = TRUE) %>%  
  pivot_longer(cols = c(LEAF, TOTAL, STEM, ROOT),
               values_to = "Weight") %>% 
  ggplot(aes(x = TREAT, y = Weight)) + 
  geom_bar(stat = "identity") + 
  facet_grid(CLONE ~ name) + 
  geom_text(aes(label = round(Weight, 1), y = Weight + 4)) + 
  theme(axis.text.y = element_blank(), axis.ticks.y = element_blank())

harvest %>% # Distribution of log-weight by Measurement and Clone
  pivot_longer(cols = c(LEAF, TOTAL, STEM, ROOT),
               values_to = "Weight") %>% 
  ggplot(aes(x = log(Weight))) + 
  geom_histogram() +
  facet_grid(CLONE ~ name)

harvest %>% 
  select(CHAMB, TREAT, PLANT, CLONE, LEAF, ROOT, STEM, TOTAL) %>% 
  pivot_longer(cols = c(LEAF, TOTAL, STEM, ROOT),
               values_to = "Weight") %>% 
  ggplot() + 
  aes(x = TREAT, y = log(Weight)) + 
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75)) + 
  facet_wrap(. ~ name) 
#+ geom_text(aes(label = CHAMB:PLANT))

#T4, CH8, PLT28
#T1, CH1, PLT45

harvest %>% 
  group_by(TREAT, CLONE) %>% 
  select(TOTAL, STEM, LEAF, ROOT) %>% 
  summarise_all(mean, na.rm = TRUE) %>% 
  pivot_wider(names_from = CLONE,
              values_from = c("TOTAL", "STEM", "LEAF", "ROOT")) %>% 
  select(starts_with("TOTAL"))


# Combine Date --------------------------------------------------------
aspen90 <- clone90 %>% 
  select(TREAT, CHAMB, PLANT, CLONE, HT1, DIAM1, HT4, DIAM4) %>% 
  mutate(VOL_bl = HT1 * DIAM1^2,
         VOL_h = HT4 * DIAM4^2) %>% 
  left_join(harvest, by = c("CHAMB", "PLANT", "CLONE")) %>% 
  mutate(PLANT = as_factor(PLANT),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01),
         LOGSTEM = log(STEM + 0.01),
         LOGLEAF = log(LEAF + 0.01),
         LOGCOARSE = log(COARSE + 0.01),
         LOGFINE = log(FINE + 0.01),
         LOGROOT = log(ROOT + 0.01),
         LOGTOTAL = log(TOTAL + 0.01))

aspen90 %>% group_by(TREAT.x, TREAT.y) %>% tally() # Discrepancies with differing Treatment codes
aspen90 %>% filter(is.na(TREAT.y)) # Which obs don't have Treat.y?

aspen90 %>% 
  group_by(TREAT.x, CLONE) %>% 
  select(TOTAL, STEM, LEAF, ROOT) %>% 
  summarise_all(mean, na.rm = TRUE) %>% 
  pivot_wider(names_from = CLONE,
              values_from = c("TOTAL", "STEM", "LEAF", "ROOT")) %>% 
  select(starts_with("TOTAL"))

# Guess is that treatment levels are coded differently between the two datasets

# Exploratory Data Analysis -------------------------------------------------------

clone90_long <- clone90 %>% 
  pivot_longer(cols = c(HT1, HT2, HT3, HT4, DIAM1, DIAM2, DIAM3, DIAM4),
               names_to = c("Measurement", "Step"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(VOL = HT * DIAM^2,
         LOGVOL = log(VOL + 0.01),
         ID = CHAMB:PLANT)

clone90_long %>% # LOGVOL over time
  ggplot() + 
  aes(x = Step, y = LOGVOL, group = ID) + 
  geom_line() + 
  facet_wrap(. ~ TREAT)

vol_change <- aspen90 %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGVOL_h, color = TREAT.x, shape = CLONE) + 
  geom_point() 

#vol_change + geom_smooth(method = "lm", se = FALSE) 

vol_change + 
  geom_smooth(method = "lm", se = FALSE, aes(group = CLONE), 
              linetype = "dashed")

vol_change + 
  facet_wrap(. ~ CHAMB)

# Look at Ozone -------------------------------------------------------------------

oz90_long <- oz90 %>% 
  pivot_longer(cols = starts_with("OZ") | starts_with("SDOZ"),
               names_to = c("Measurement", "Level"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value)

ord_CHAMB <- as.character(1:18)

oz90_long <- oz90_long %>% # Recode the chambers
  mutate(CHAMB = case_when(Level == "18" ~ "1",
                           Level == "02" ~ "2",
                           Level == "13" ~ "3",
                           Level == "06" ~ "4",
                           Level == "04" ~ "5",
                           Level == "08" ~ "6",
                           Level == "14" ~ "7",
                           Level == "05" ~ "8",
                           Level == "03" ~ "9",
                           Level == "01" ~ "10",
                           Level == "17" ~ "11",
                           Level == "12" ~ "12",
                           Level == "10" ~ "13",
                           Level == "09" ~ "14",
                           Level == "07" ~ "15",
                           Level == "15" ~ "16",
                           Level == "16" ~ "17",
                           TRUE ~ "18")) %>% 
  mutate(CHAMB = factor(CHAMB, levels = ord_CHAMB))

oz90_long %>% 
  left_join(clone90 %>% select(TREAT, CHAMB)) %>% 
  ggplot() + 
  aes(x = datetime, y = OZ/1000, color = TREAT) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ CHAMB, nrow = 3)



oz90_long %>% 
  filter(CHAMB == 18) %>% 
  ggplot() + 
  aes(x = datetime, y = OZ/1000) + 
  geom_line() + 
  theme_bw() + 
  facet_wrap(. ~ CHAMB)


chamb18 <- oz90_long %>% filter(CHAMB == 18) 
id <- rep(NA, nrow(chamb18))
start <- 1
for(i in 1:nrow(chamb18)){
  if(is.na(chamb18$OZ[i]) & start %% 2 == 1){id[i] = start}
  if(is.na(chamb18$OZ[i]) & start %% 2 == 0){id[i] = start + 1; start = start + 1}
  if(!is.na(chamb18$OZ[i]) & start %% 2 == 0){id[i] = start}
  if(!is.na(chamb18$OZ[i]) & start %% 2 == 1){id[i] = start + 1; start = start + 1}
}

missing_time <- chamb18 %>% 
  mutate(id = id) %>% 
  group_by(id) %>% 
  slice(c(1, n())) %>% 
  select(datetime, CHAMB, id) %>%
  mutate(sequence = rep(c("start", "end"))) %>% 
  pivot_wider(names_from = sequence, values_from = datetime) %>% 
  mutate(is_missing = factor(ifelse(id %% 2 == 1, "Missing", "Non-missing")),
         end = end + hms::hms(hours = 1))

oz90_long %>% 
  filter(CHAMB == 18) %>% 
  ggplot() + 
  geom_line(aes(x = datetime, y = OZ/1000)) + 
  geom_rect(data = missing_time, 
            aes(xmin = start, xmax = end, fill = is_missing),
            ymin = -Inf, ymax = Inf, alpha = 0.35) + 
  theme_bw() + 
  facet_wrap(. ~ CHAMB) 

summ_stats_oz <- oz90_long %>% 
  group_by(CHAMB, Level) %>% 
  summarize(mean = mean(OZ, na.rm = TRUE),
            sd = sd(OZ, na.rm = TRUE),
            median = median(OZ, na.rm = TRUE), 
            n = n(),
            NAs = sum(is.na(OZ)),
            prop_NA = NAs / n)
summ_stats_oz # Looking at summary of OZ and missingness

summ_stats_oz %>% 
  ggplot() + 
  aes(x = CHAMB, y = prop_NA) + 
  geom_bar(stat = "identity")

# Create OZ Metrics -----------------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/KARNOSKY/Seiji's Work/OZ_metrics_KARN.R")

exp_days <- as.numeric(max(oz90_long$date) - min(oz90_long$date) + 1)

stest <- OZ_metrics_KARN(oz90_long) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

stest %>% select(CHAMB, w126.12.8.adj)

test_long <- full_join(aspen90 %>% select(TREAT.x, CHAMB, PLANT, CLONE, LOGVOL_bl, LOGLEAF, LOGSTEM, LOGROOT, LOGTOTAL),
                       stest)

#write.csv(test_long, "aspen_clone_90_data.csv")

# Combine Maple Data with OZ metrics -------------------------------------------
test.df <- aspen90 %>% 
  group_by(TREAT.x, CHAMB, CLONE) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl, LEAF, STEM, ROOT, TOTAL, COARSE, FINE), mean, na.rm = TRUE) 

combined_data <- left_join(test.df, stest) %>% 
  mutate(Year = 1990,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

combined_data2 <- combined_data %>% 
  rename(LOGSTEMDW = LOGSTEM,
         LOGLEAFDW = LOGLEAF,
         LOGROOTDW = LOGROOT,
         LOGCOARSEDW = LOGCOARSE,
         LOGFINEDW = LOGFINE,
         LOGTOTALDW = LOGTOTAL,
         STEMDW = STEM,
         LEAFDW = LEAF,
         COARSEDW = COARSE,
         FINEDW = FINE,
         ROOTDW = ROOT,
         TOTALDW = TOTAL,
         TREAT = TREAT.x)

#write.csv(combined_data, "aspen_clone_90_mean_data.csv")
#write.csv(combined_data2, "aspen_clone_90_mean_data.csv", row.names = FALSE)

