library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in data -------------------------------------

oz91 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/OZONE/ozone91dk.csv")

clone91 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/ASPEN/CLONE/CLON1991.csv")

# Clean up data ------------------------------------
noNA <- function(x){ifelse(x == -99, NA, x)} # Sets -99 to NA
noNeg <- function(x){ifelse(x < 0, 0, x)} # Sets erroneous negative values to 0

oz91 <- oz91 %>% 
  mutate(date = make_date(1900 + year, month, day),
         datetime = make_datetime(1900 + year, month, day, hour)) %>% # Create Date variables
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNA) %>% 
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNeg)

clone91 <- clone91 %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(TREAT = as_factor(TREAT),
         CHAMB = as_factor(CHAMBER),
         CLONE = as_factor(CLONE),
         TOTAL = STEM + LEAF + ROOT
  )

clone91 %>% 
  group_by(TREAT, CLONE) %>% 
  summarize_at(vars(LEAF, TOTAL, STEM, ROOT), mean, na.rm = TRUE) %>%  
  pivot_longer(cols = c(LEAF, TOTAL, STEM, ROOT),
               values_to = "Weight") %>% 
  ggplot(aes(x = TREAT, y = Weight)) + 
  geom_bar(stat = "identity") + 
  facet_grid(CLONE ~ name) + 
  geom_text(aes(label = round(Weight, 1), y = Weight + 2)) + 
  theme(axis.text.y = element_blank(), axis.ticks.y = element_blank())


# Combine Date --------------------------------------------------------
aspen91 <- clone91 %>% 
  select(TREAT, CHAMB, CLONE, HTO, DIAMO, HT4, DIAM4,
         STEM, LEAF, ROOT, TOTAL) %>% 
  mutate(VOL_bl = HTO * DIAMO^2,
         VOL_h = HT4 * DIAM4^2,
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01),
         LOGSTEM = log(STEM + 0.01),
         LOGLEAF = log(LEAF + 0.01),
         LOGROOT = log(ROOT + 0.01),
         LOGTOTAL = log(TOTAL + 0.01))

aspen91 %>% group_by(TREAT, CHAMB) %>% tally()


# Exploratory Data Analysis -------------------------------------------------------

clone91_long <- clone91 %>% 
  rename(HT0 = HTO,
         DIAM0 = DIAMO) %>% 
  mutate(ID = 1:nrow(clone91)) %>% 
  pivot_longer(cols = c(HT0, HT1, HT2, HT3, HT4, DIAM0, DIAM1, DIAM2, DIAM3, DIAM4),
               names_to = c("Measurement", "Step"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(VOL = HT * DIAM^2,
         LOGVOL = log(VOL + 0.01))

clone91_long %>% 
  ggplot() + 
  aes(x = Step, y = LOGVOL, group = ID) + 
  geom_line() + 
  facet_wrap(. ~ TREAT)

vol_change <- aspen91 %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGVOL_h, color = TREAT, shape = CLONE,
      linetype = CLONE) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) 

vol_change + 
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), 
              linetype = "dashed", color = "black")

vol_change + 
  facet_wrap(. ~ CHAMB)

# Look at Ozone -------------------------------------------------------------------

oz91_long <- oz91 %>% 
  pivot_longer(cols = starts_with("OZ") | starts_with("SDOZ"),
               names_to = c("Measurement", "Level"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(CHAMB = factor(as.numeric(Level)))


oz91_long %>% 
  filter(CHAMB %in% unique(levels(aspen91$CHAMB))) %>% 
  ggplot() + 
  aes(x = datetime, y = OZ/1000) + 
  geom_line() + 
  facet_wrap(. ~ CHAMB)

summ_stats_oz <- oz91_long %>% 
  filter(CHAMB %in% unique(levels(aspen91$CHAMB))) %>% 
  group_by(CHAMB, Level) %>% 
  summarize(mean = mean(OZ, na.rm = TRUE),
            sd = sd(OZ, na.rm = TRUE),
            median = median(OZ, na.rm = TRUE), 
            n = n(),
            NAs = sum(is.na(OZ)),
            prop_NA = NAs / n)
summ_stats_oz

summ_stats_oz %>% 
  ggplot() + 
  aes(x = CHAMB, y = prop_NA) + 
  geom_bar(stat = "identity")

# Create OZ Metrics -----------------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/KARNOSKY/Seiji's Work/OZ_metrics_KARN.R")

exp_days <- as.numeric(max(oz91_long$date) - min(oz91_long$date) + 1)

stest <- OZ_metrics_KARN(oz91_long) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(aspen91 %>% select(TREAT, CHAMB, CLONE, LOGVOL_bl, LOGLEAF, LOGSTEM, LOGROOT, LOGTOTAL),
                       stest)

#write.csv(test_long, "aspen_clone_91_data.csv")

# Combine Maple Data with OZ metrics -------------------------------------------

test.df <- aspen91 %>% 
  group_by(TREAT, CHAMB, CLONE) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl, LEAF, ROOT, STEM, TOTAL), mean, na.rm = TRUE) 

combined_data <- left_join(test.df, stest) %>% 
  mutate(Year = 1991,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

combined_data2 <- combined_data %>% 
  rename(LOGSTEMDW = LOGSTEM,
         LOGLEAFDW = LOGLEAF,
         LOGROOTDW = LOGROOT,
         LOGTOTALDW = LOGTOTAL,
         STEMDW = STEM,
         LEAFDW = LEAF,
         ROOTDW = ROOT,
         TOTALDW = TOTAL)

#write.csv(combined_data, "aspen_clone_91_mean_data.csv")
#write.csv(combined_data2, "aspen_clone_91_mean_data.csv", row.names = FALSE)
