library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in data -------------------------------------

oz91 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/OZONE/ozone91dk.csv")

seed91 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/ASPEN/SEEDLING/SEED1991.csv")

# Clean up data ------------------------------------
noNA <- function(x){ifelse(x == -99, NA, x)} # Sets -99 to NA
noNeg <- function(x){ifelse(x < 0, 0, x)} # Sets erroneous negative values to 0

oz91 <- oz91 %>% 
  mutate(date = make_date(1900 + year, month, day),
         datetime = make_datetime(1900 + year, month, day, hour)) %>% # Create Date variables
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNA) %>% 
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNeg)

seed91 <- seed91 %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(TREAT = as_factor(TREAT),
         CHAMBER = as_factor(CHAMBER),
         PLANT = as_factor(PLANT),
         TOTAL = LEAF + STEM + ROOT,
         VOL_bl = HTO * DIAMO^2,
         VOL_h = HT4 * DIAM4^2,
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01),
         LOGSTEM = log(STEM + 0.01),
         LOGLEAF = log(LEAF + 0.01),
         LOGROOT = log(ROOT + 0.01),
         LOGTOTAL = log(TOTAL + 0.01))

seed91 %>% group_by(TREAT, CHAMBER) %>% tally()

# Exploratory Data Analysis -------------------------------------------------------

seed91_long <- seed91 %>% 
  rename(HT0 = HTO,
         DIAM0 = DIAMO) %>% 
  pivot_longer(cols = c(HT0, HT1, HT2, HT3, HT4, DIAM0, DIAM1, DIAM2, DIAM3, DIAM4),
               names_to = c("Measurement", "Step"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(VOL = HT * DIAM^2,
         LOGVOL = log(VOL + 0.01))

seed91_long %>% 
  ggplot() + 
  aes(x = Step, y = LOGVOL, group = CHAMBER:PLANT) + 
  geom_line() + 
  facet_wrap(. ~ TREAT)

vol_change <- seed91 %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGVOL_h, color = TREAT) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) 

vol_change + 
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), 
              linetype = "dashed", color = "black")

vol_change + 
  facet_wrap(. ~ CHAMBER)

# Look at Ozone -------------------------------------------------------------------

oz91_long <- oz91 %>% 
  pivot_longer(cols = starts_with("OZ") | starts_with("SDOZ"),
               names_to = c("Measurement", "Level"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(CHAMB = factor(as.numeric(Level)))


oz91_long %>% 
  ggplot() + 
  aes(x = datetime, y = OZ/1000) + 
  geom_line() +  
  facet_wrap(. ~ CHAMB)

summ_stats_oz <- oz91_long %>% 
  group_by(CHAMB, Level) %>% 
  summarize(mean = mean(OZ, na.rm = TRUE),
            sd = sd(OZ, na.rm = TRUE),
            median = median(OZ, na.rm = TRUE), 
            n = n(),
            NAs = sum(is.na(OZ)),
            prop_NA = NAs / n)
summ_stats_oz

summ_stats_oz %>% 
  ggplot() + 
  aes(x = CHAMB, y = prop_NA) + 
  geom_bar(stat = "identity")

# Create OZ Metrics -----------------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/KARNOSKY/Seiji's Work/OZ_metrics_KARN.R")

exp_days <- as.numeric(max(oz91_long$date) - min(oz91_long$date) + 1)

stest <- OZ_metrics_KARN(oz91_long) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(seed91 %>% select(TREAT, CHAMBER, PLANT, LOGVOL_bl, LOGLEAF, LOGSTEM, LOGROOT, LOGTOTAL) %>% 
                         rename(CHAMB = CHAMBER),
                       stest)

#write.csv(test_long, "aspen_seed_91_data.csv", row.names = FALSE)

# Combine Maple Data with OZ metrics -------------------------------------------

test.df <- seed91 %>% 
  rename(LEAFDW = LEAF,
         STEMDW = STEM,
         ROOTDW = ROOT,
         TOTALDW = TOTAL,
         LOGLEAFDW = LOGLEAF,
         LOGSTEMDW = LOGSTEM,
         LOGROOTDW = LOGROOT,
         LOGTOTALDW = LOGTOTAL) %>% 
  group_by(TREAT, CHAMBER) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE)

combined_data <- left_join(test.df, stest %>% rename(CHAMBER = CHAMB)) %>% 
  mutate(Year = 1991,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

combined_data %>% 
  group_by(TREAT) %>% 
  summarise(m1 = round(mean(w126.12.8.adj), 1),
            m2 = round(mean(aot40.12.8.adj), 1)) %>% 
  arrange(m1)


qplot(combined_data$LOGVOL_bl, combined_data$LOGTOTALDW)

#write.csv(combined_data, "aspen_seed_mean_data.csv", row.names = FALSE)
