library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in data -------------------------------------

oz90 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/OZONE/ozone90dk.csv")

maple90 <- read_csv("C:/Users/skoike/Desktop/tidy data/KARNOSKY/MAPLE/MAPLES90.csv")

# Clean up data ------------------------------------
noNA <- function(x){ifelse(x == -99, NA, x)} # Sets -99 to NA
noNeg <- function(x){ifelse(x < 0, 0, x)} # Sets erroneous negative values to 0

oz90 <- oz90 %>% 
  mutate(date = make_date(1900 + year, month, day),
         datetime = make_datetime(1900 + year, month, day, hour)) %>% # Create Date variables
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNA) %>% 
  mutate_at(vars(starts_with("OZ") | starts_with("SD")), noNeg)

maple90 <- maple90 %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(TOTAL = LEAF + STEM + ROOT, # Create other response variables
         CHAMB = as_factor(CHAMB),
         LOGLEAFDW = log(LEAF + 0.01),
         LOGSTEMDW = log(STEM + 0.01),
         LOGROOTDW = log(ROOT + 0.01),
         LOGTOTALDW = log(TOTAL + 0.01)) %>% 
  rename(LEAFDW = LEAF,
         STEMDW = STEM,
         ROOTDW = ROOT,
         TOTALDW = TOTAL)

# Exploratory Data Analysis -------------------------

maple90_long <- maple90 %>% 
  pivot_longer(cols = c(HT1, HT2, HT3, HT4, DIAM1, DIAM2, DIAM3, DIAM4), 
               names_to = c("Measurement", "Step"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(VOL = HT * DIAM^2,
         LOGVOL = log(VOL + 0.01),
         ID = as_factor(CHAMB):as_factor(PLANT))

maple90_wide <- maple90_long %>% 
  pivot_wider(names_from = Step, 
              values_from = c("HT", "DIAM", "VOL", "LOGVOL"))

maple90_wide %>% select(DIAM_1, HT_1)

maple90_wide %>% 
  group_by(CHAMB) %>% 
  summarise(weird = sum(LOGVOL_4 < LOGVOL_1)) # One end volume smaller than initial

maple90 <- maple90 %>% 
  select(-starts_with("HT"), -starts_with("DIAM")) %>% 
  full_join(maple90_wide) %>% 
  mutate(TREAT = as_factor(TREAT))

maple90 %>% 
  filter(.$LOGVOL_4 < .$LOGVOL_1) %>% 
  pivot_longer(cols = c(LOGVOL_1, LOGVOL_4)) %>% 
  ggplot() + 
  aes(x = name, y = value, group = ID) + 
  geom_text(aes(label = ID)) + 
  geom_line() + 
  facet_wrap(. ~ TREAT) # Here it is!


vol_change <- maple90 %>% 
  ggplot() + 
  aes(x = LOGVOL_1, y = LOGVOL_4, color = TREAT) + 
  geom_point(size = 2) + 
  scale_color_manual(values = brewer.pal(6, "Dark2")) + 
  geom_smooth(method = "lm", se = FALSE) 

vol_change + 
  geom_smooth(method = "lm", linetype = "dashed", color = "black",
              aes(group = 1))

vol_change + 
  facet_wrap(. ~ TREAT) + 
  geom_abline(slope = 1, intercept = 0, linetype = "dashed")


oz90_long <- oz90 %>% 
  pivot_longer(cols = starts_with("OZ") | starts_with("SDOZ"),
               names_to = c("Measurement", "Level"),
               names_pattern = "([A-Za-z]+)(\\d+)") %>% 
  pivot_wider(names_from = Measurement,
              values_from = value)

ord_CHAMB <- as.character(1:18)

oz90_long <- oz90_long %>% 
    mutate(CHAMB = case_when(Level == "18" ~ "1",
                             Level == "02" ~ "2",
                             Level == "13" ~ "3",
                             Level == "06" ~ "4",
                             Level == "04" ~ "5",
                             Level == "08" ~ "6",
                             Level == "14" ~ "7",
                             Level == "05" ~ "8",
                             Level == "03" ~ "9",
                             Level == "01" ~ "10",
                             Level == "17" ~ "11",
                             Level == "12" ~ "12",
                             Level == "10" ~ "13",
                             Level == "09" ~ "14",
                             Level == "07" ~ "15",
                             Level == "15" ~ "16",
                             Level == "16" ~ "17",
                             TRUE ~ "18")) %>% 
    mutate(CHAMB = factor(CHAMB, levels = ord_CHAMB))

oz90_long %>% 
  left_join(., maple90 %>% select(TREAT, CHAMB)) %>% 
  #filter(CHAMB %in% c(11, 10, 18, 12, 17, 15)) %>% 
  ggplot() + 
  aes(x = datetime, y = OZ/1000, color = TREAT) + 
  geom_line() +
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ CHAMB, nrow = 3) + 
  theme(panel.background = element_rect(fill = "grey80"))

summ_stats_oz <- oz90_long %>% 
    group_by(CHAMB, Level) %>% 
    summarize(mean = mean(OZ, na.rm = TRUE),
              sd = sd(OZ, na.rm = TRUE),
              median = median(OZ, na.rm = TRUE), 
              n = n(),
              NAs = sum(is.na(OZ)),
              prop_NA = NAs / n)
summ_stats_oz

summ_stats_oz %>% 
  ggplot() + 
  aes(x = CHAMB, y = prop_NA) + 
  geom_bar(stat = "identity")

# Create OZ Metrics -----------------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/KARNOSKY/Seiji's Work/OZ_metrics_KARN.R")

exp_days <- as.numeric(max(oz90_long$date) - min(oz90_long$date) + 1)

stest <- OZ_metrics_KARN(oz90_long) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(maple90 %>% select(TREAT, CHAMB, PLANT, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_1),
                       stest)

#write.csv(test_long, "sugarmaple_data.csv", row.names = FALSE)

# By hand to double check

by_hand <- oz90_long %>% 
  filter(hour > 7, hour < 20) %>% 
  group_by(CHAMB) %>% 
  summarise(n = n(),
            non_NA = sum(!is.na(OZ)),
            scale = n/non_NA,
            w126.12.8.adj = 
              sum((OZ/1000) / (1 + 4403*exp(-126*(OZ/1000))), na.rm = TRUE) * 92/exp_days * scale)

round(by_hand$w126.12.8.adj, 10) == round(stest$w126.12.8.adj, 10)    
    
# Combine Maple Data with OZ metrics -------------------------------------------
test.df <- maple90 %>% 
  group_by(TREAT, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), starts_with("VOL")), mean, na.rm = TRUE) %>% 
  select(-VOL_2, -VOL_3, -VOL_4, -LOGVOL_2, -LOGVOL_3, -LOGVOL_4) %>% 
  rename(LOGVOL_bl = LOGVOL_1, VOL_bl = VOL_1)

combined_data <- full_join(test.df, stest) %>% 
  mutate(Year = 1990,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(combined_data, "sugarmaple_mean_data.csv", row.names = FALSE)
