library(tidyverse)
library(lme4)

# Since the parameters are quite close to those of the Harvest 1 model, let's try combining them
####################################################################

study_90 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tpop_90_mean_data.csv") %>% 
  mutate(Study = factor("1990"),
         Site = "SMNP") 
study_91 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tpop_91_mean_data.csv") %>% 
  mutate(Study = factor("1991"),
         Site = "SMNP")
study_92 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tpop_92_mean_data.csv") %>% 
  mutate(Study = factor("1992"),
         Site = "SMNP") 

studies <- full_join(study_90, study_91) %>%
  full_join(study_92) %>% 
  rename(actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj)

TP <- studies %>%
  mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl),
         TREAT = case_when(TREAT == 1 ~ "CF",
                           TREAT == 2 ~ "0.5x",
                           TREAT == 3 ~ "1x",
                           TREAT == 4 ~ "1.5x",
                           TREAT == 5 ~ "2x",
                           TRUE ~ "AA"),
         TREAT = as_factor(TREAT),
         Species = "Tulip Poplar")

TP %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Study, m)

TP1 <- TP %>% 
  filter(TREAT != "AA") %>% 
  group_by(Study, Harvest) %>% 
  mutate(has_cov = ifelse(Study != 1990, 1, 0),
         is_90 = ifelse(Study == 1990, 1, 0),
         LOGVOL_bl = ifelse(is.na(LOGVOL_bl), 0, LOGVOL_bl),
         cov = LOGVOL_bl * has_cov,
         centered_logvol = cov - mean(cov),
         is_h2 = ifelse(Harvest == 1, 0, 1),
         Harvest = as_factor(Harvest)) %>%
  ungroup() 

TP2 <- full_join(TP %>% 
                   filter(TREAT == "AA") %>% 
                   mutate(Harvest = as_factor(Harvest),
                          is_90 = ifelse(Study == 1990, 1, 0),
                          is_h2 = ifelse(Harvest == 1, 0, 1)), 
                 TP1) %>%
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), is_90, is_h2, centered_logvol, LOGVOL_bl, VOL_bl,
         everything(), -has_cov, -cov)

TP2 %>% nest_by(Study, Exp_days)

#write.csv(TP2, "tp_chamber_mean_data.csv", row.names = FALSE)


TP <- TP1 %>% 
  select(Harvest, Study, LOGTOTALDW, w126.12.8.adj, centered_logvol, is_h2, is_90)

ggplot(TP) + 
  aes(x = centered_logvol, y = LOGTOTALDW, color = Study, shape = Harvest) + 
  geom_point(size = 2.5, alpha = 0.7) + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")

ggplot(TP) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study, shape = Harvest) + 
  geom_point(size = 2.5, color = "black", alpha = 0.7) + 
  geom_smooth(method = "lm", se = FALSE) +
  scale_shape_manual(values = c(21, 24)) +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")


fitmodel <- function(df){lm(LOGTOTALDW ~ centered_logvol, data = df)}

TP %>% 
  group_by(Study, Harvest) %>% 
  nest() %>% 
  mutate(model = map(data, fitmodel),
         tidied = map(model, broom::tidy)) %>% 
  unnest(tidied) %>% 
  filter(term == "centered_logvol")


# Random Coefficient Model -----------------------------------------------------


# Model 1
# Common B, C, Covariate
# Separate Intercept

nform1 <- ~ log(a + a2*is_h2 + a90*is_90 + d*logvol) + (-(x/b)^c) 

nfun1 <- deriv(nform1,
               namevec = c("a", "a2", "a90", "b", "c", "d"),
               function.arg = c("x", "logvol", "is_h2", "is_90", "a", "a2", "a90", "b", "c", "d"))

nl1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, is_h2, is_90, a, a2, a90, b, c, d) ~ a + b + c| Study,
             data = TP,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 10, a2 = 1, a90 = 1, b = 10, c = 1, d = 1))
summary(nl1) # B = 45, C = 0.3

aug1 <- broom.mixed::augment(nl1)  

aug1 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")


# Model 2
# Common B, Covariate,
# C = 1
# Separate Intercept

nform2 <- ~ log(a + a2*is_h2 + a90*is_90 + d*logvol) + (-(x/b))

nfun2 <- deriv(nform2,
               namevec = c("a", "a2", "a90", "b", "d"),
               function.arg = c("x", "logvol", "is_h2", "is_90", "a", "a2", "a90", "b", "d"))

nl2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, is_h2, is_90, a, a2, a90, b, d) ~ (a | Study) + (b|Study),
             data = TP,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 10, a2 = 1, a90 = 1, b = 10, d = 1))
summary(nl2) # B = 63, C = 1

aug2 <- broom.mixed::augment(nl2)  

aug2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")

# Model 3
# Common B, C, No Covariate
# Separate Intercept

# Model 1
# Common B, C, Covariate
# Separate Intercept

nform3 <- ~ log(a + a2*is_h2 + a90*is_90) + (-(x/b)^c) 

nfun3 <- deriv(nform3,
               namevec = c("a", "a2", "a90", "b", "c"),
               function.arg = c("x", "is_h2", "is_90", "a", "a2", "a90", "b", "c"))

nl3 <- nlmer(LOGTOTALDW ~ nfun3(w126.12.8.adj, is_h2, is_90, a, a2, a90, b, c) ~ a + b + c | Study,
             data = TP,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 10, a2 = 1, a90 = 1, b = 10, c = 1))
summary(nl3) # B = 373, C = 0.3

aug3 <- broom.mixed::augment(nl3)  

aug3 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")


# Model 4
# Common B, C = 1, No Covariate
# Separate Intercept

nform4 <- ~ log(a + a2*is_h2 + a90*is_90) + (-(x/b)) # Log of intercept term won't converge

nfun4 <- deriv(nform4,
               namevec = c("a", "a2", "a90", "b"),
               function.arg = c("x", "is_h2", "is_90", "a", "a2", "a90", "b"))

nl4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, is_h2, is_90, a, a2, a90, b) ~ a + b | Study,
             data = TP,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 10, a2 = 1, a90 = 1, b = 10))
summary(nl4) # B = 69.6, C = 1

aug4 <- broom.mixed::augment(nl4)  

aug4 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")


# Model 6
# Common B, C, Covariate
# Separate Intercept

nform6 <- ~ log(a + a2*is_h2 + d*logvol) + (-(x/b)) 

nfun6 <- deriv(nform6,
               namevec = c("a", "a2", "b", "d"),
               function.arg = c("x", "logvol", "is_h2", "a", "a2", "b", "d"))

nl6 <- nlmer(LOGTOTALDW ~ nfun6(w126.12.8.adj, centered_logvol, is_h2, a, a2, b, d) ~ (a|Study) + (b|Study),
             data = TP,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 10, a2 = 1, b = 10, d = 1))
summary(nl6) # B = 63, C = 1

aug6 <- broom.mixed::augment(nl6)  

aug6 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")

# Comparing Models --------------------------------------------------------------------------------
nform1 # Covariate, estimated c
nform2 # Covariate, C = 1
nform3 # No Covariate, estimated C
nform4 # No Covariate, C = 1
nform6 # No separate 1990 intercept, C = 1

fixef(nl1)
fixef(nl2)
fixef(nl3)
fixef(nl4)
fixef(nl6)

mean(aug1$.resid^2) # smallest
mean(aug2$.resid^2) 
mean(aug3$.resid^2) 
mean(aug4$.resid^2) 
mean(aug6$.resid^2) 

(SSRes1 <- sum(aug1$.resid^2)) # smallest
(SSRes2 <- sum(aug2$.resid^2))
(SSRes3 <- sum(aug3$.resid^2))
(SSRes4 <- sum(aug4$.resid^2))
(SSRes6 <- sum(aug4$.resid^2))

meanY <- mean(aug1$LOGTOTALDW)
SStot <- sum((aug1$LOGTOTALDW - meanY)^2) 

(r_sq_1 <- 1 - SSRes1/SStot) # Largest
(r_sq_2 <- 1 - SSRes2/SStot)  
(r_sq_3 <- 1 - SSRes3/SStot) 
(r_sq_4 <- 1 - SSRes4/SStot) 
(r_sq_6 <- 1 - SSRes6/SStot) 

anova(nl2, nl1)
anova(nl6, nl2)

SSreg <- sum((aug2$.fitted - meanY)^2)
SSreg/SStot

# Even though nl1 fits better, nl2 fits almost as well and is a simpler model

# Model b: Separate B by harvest
nform2

nlformb <- ~ log(a1 + a2*is_h2 + a3*is_90 + d*centered_logvol) + (-(x/(b + b2*is_h2)))

nlfunb <- deriv(nlformb,
                namevec = c("a1", "a2", "a3", "b", "b2", "d"),
                function.arg = c("x", "is_h2", "is_90", "centered_logvol", "a1", "a2", "a3", "b", "b2", "d"))

nlb <- nlmer(LOGTOTALDW ~ nlfunb(w126.12.8.adj, is_h2, is_90, centered_logvol, a1, a2, a3, b, b2, d) ~ (a1|Study) + (b|Study),
             data = TP, 
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a1 = 10, a2 = 1, a3 = 1, b = 100, b2 = 1, d = 1))
summary(nlb) #b1 = 57.4, b2 = 20.7

lmtest::lrtest(nl2, nlb)




# Figure ?
nform2
broom::tidy(nl2) 
(coef_mod <- fixef(nl2))

TP <- TP %>% 
  mutate(adj_y = LOGTOTALDW - log(coef_mod[1] + coef_mod[2]*is_h2 + coef_mod[3]*is_90 + coef_mod[5]*centered_logvol))

pred <- tibble(w126.12.8.adj =  c(seq(0, max(TP$w126.12.8.adj), by = 0.5), max(TP$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[4]))

TP_plot <- ggplot(TP) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = Harvest, fill = Study)) + 
  geom_line(data = pred, size = 1) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21)))

TP_plot

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[4]))), 1) 

tp_lines <- ggplot_build(TP_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Tulip Poplar"))

#write.csv(tp_lines, "tp_lines.csv", row.names = FALSE)

y_hat <- -(TP$w126.12.8.adj/coef_mod[4])
y <- TP$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 

tp_b <- tibble(b = coef_mod[4], c = 1, Species = "Tulip Poplar")

#write.csv(tp_b, "tp_params.csv", row.names = FALSE)
#write.csv(coef_mod, "tp_all_params.csv")

w126_frame <- TP %>% 
  group_by(Study, Harvest) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nl2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b")) %>% 
  rename(b = Study.b)

TP_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b))

nform2

intercept_frame <- coef(nl2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a, Study.a2, Study.a90, Study.d)


TP_points <- full_join(TP, intercept_frame) %>%
  rename(a = Study.a, 
         a2 = Study.a2,
         a90 = Study.a90,
         d = Study.d) %>% 
  mutate(adj_y = LOGTOTALDW - log(a + a2*is_h2 + a90*is_90 + d*centered_logvol))

TP_sub <- TP %>% select(Study, Harvest) %>% mutate(Model = factor("Overall"))

pred1_a <- pred %>% 
  mutate(Model = factor("Overall")) %>% 
  full_join(TP_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

TP_lines <- TP_lines %>% mutate(Model = factor("Individual"))

pred <- full_join(TP_lines, pred1_a)

ggplot(TP_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = Harvest, fill = Study)) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21))) + 
  facet_wrap(. ~ Study, nrow = 2) + 
  geom_line(data = pred %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  scale_color_brewer(palette = "Set1") + 
  geom_line(data = pred %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

ggplot(TP_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = Harvest, fill = Study)) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21)),
         shape = FALSE) + 
  facet_wrap(. ~ Harvest) + 
  geom_line(data = pred %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  scale_color_brewer(palette = "Set1") + 
  geom_line(data = pred %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

#write.csv(TP_points, "tp_figure_points.csv", row.names = FALSE)
#write.csv(pred, "tp_figure_pred.csv", row.names = FALSE)

# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- TP$LOGTOTALDW
x <- TP$w126.12.8.adj
Study <- TP$Study
is_h2 <- TP$is_h2
is_90 <- TP$is_90
logvol <- TP$centered_logvol

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)
nform2

nlform_k <- ~ log(a + a2*is_h2 + a90*is_90 + d*logvol) + ((x/x0) * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "a2", "a90", "d", "theta"),
                 function.arg = c("x", "x0", "logvol", "is_h2", "is_90", "a", "a2", "a90", "d", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.01) # 51 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks) + 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, is_h2, is_90, a, a2, a90, d, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(rep(Inf, 6), 1),
                                                      lower = c(rep(-Inf, 6), 0))),
                start = c(a = 10, a2 = 1, a90 = 1, d = 1, theta = 0.6))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, is_h2, is_90, a, a2, a90, d, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                       control = nlmerControl(optimizer = "bobyqa",
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(rep(Inf, 6), theta_lim + 0.005),
                                                             lower = c(rep(-Inf, 6), theta_lim - 0.005))),
                       start = c(a = 10, a2 = 1, a90 = 1, d = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

LL
ll_hat
mle
#write.csv(LL, "tp_LL_profile.csv", row.names = FALSE)
#write.csv(ll_hat, "tp_ll_hat.csv", row.names = FALSE)
#write.csv(mle, "tp_mle_combined.csv", row.names = FALSE)

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")



LL_1 <- LL 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-breaks/coef_mod[4])

adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l", xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)

# Write file

write.csv(LL_6, "tp_para_ci.csv", row.names = FALSE)
